arima.ARIMAParams

Parameters for the ARIMA model.

Usage

arima.ARIMAParams(
    *,
    holidays=None,
    order=(0, 0, 0),
    seasonal_order=(0, 0, 0, 0),
    enforce_stationarity=True,
    max_iter=50,
    interval_width=0.95
)

Parameters

holidays: pd.DataFrame | None = None

Holiday dataframe. If None, no holiday effects are fitted.

order: tuple = (0, 0, 0)

The (p, d, q) order of the model.

seasonal_order: tuple = (0, 0, 0, 0)

The (P, D, Q, s) order of the seasonal component of the model.

enforce_stationarity: bool = True

Whether or not to require the autoregressive parameters to correspond to a stationarity process.

max_iter: int = 50

The maximum number of iterations. Using ARIMA default (50), we did observe a warning that “Maximum Likelihood optimisation failed to converge”. This warning can be resolved by increasing the maximum.

interval_width: float = 0.95
Width of the prediction intervals - for example, 0.95 will produce 95% prediction intervals.