preprocessing.expand_holiday_windows()

Create a row for each holiday date - no lower/upper windows.

Usage

preprocessing.expand_holiday_windows(data)

The holidays dataframe is formatted for Prophet with lower_window (0 or below) and upper_window (0 or above) indicating days around a date that are also holidays. This function creates a row for each date in those windows.

Parameters

data: pd.DataFrame
Holidays data.

Returns

pd.DataFrame
Restructured holidays data.