prophet.ProphetParams

Parameters for the Prophet model.

Usage

prophet.ProphetParams(
    *,
    holidays=None,
    yearly_seasonality=True,
    weekly_seasonality=True,
    daily_seasonality=False,
    seasonality_mode="additive",
    changepoint_range=0.8,
    changepoint_prior_scale=0.05,
    seasonality_prior_scale=10,
    holidays_prior_scale=10,
    regressors=(),
    interval_width=0.95,
    plot_components=False
)

For full range of parameters see: https://facebook.github.io/prophet/api/prophet.html

Parameters

holidays: pd.DataFrame | None = None

Holiday dataframe. If None, no holiday effects are fitted.

yearly_seasonality: bool | int | {auto} = True

Whether to fit yearly seasonality, which is a repeating pattern across a calendar year (e.g., peaks in certain seasons).

weekly_seasonality: bool | int | {auto} = True

Whether to fit weekly seasonality, which is a repeating pattern within a single week (e.g., peaks on certain days of the week).

daily_seasonality: bool | int | {auto} = False

Whether to fit daily seasonality, which is a repeating pattern within a day (e.g., peaks at certain hours of day).

seasonality_mode: (additive, multiplicative) = "additive"

Either “additive” (seasonal effect is add to the trend, so size of effect is constant) or “multiplicative” (seasonality effect grows with the trend). May wish to switch to multiplicative if a seasonal effect is too large near the start of a series but too small by the end.

changepoint_range: float = 0.8

Proportion of history in which trend changepoints will be estimated.

changepoint_prior_scale: float = 0.05

Parameter modulating the flexibility of the automatic changepoint selection. Large values will allow many changepoints, small values will allow few changepoints.

seasonality_prior_scale: float = 10

Parameter modulating strength of seasonality model. Larger values allow the model to fit larger seasonal fluctuations, smaller values dampen the seasonality.

holidays_prior_scale: float = 10

Parameter modulating the strength of the holiday components model.

regressors: tuple[ProphetRegressor, …] = ()

Additional regressors to add before fitting.

interval_width: float = 0.95

Width of the prediction intervals - for example, 0.95 will produce 95% prediction intervals.

plot_components: bool = False
If True, will display the Prophet plot_components figure.