prophet.ProphetRegressor

Configuration and data for a single Prophet regressor.

Usage

prophet.ProphetRegressor(
    *, name, data, prior_scale=None, standardize="auto", mode=None
)

For full documentation on Prophet regressors see: https://facebook.github.io/prophet/api/prophet.html#Prophet.add_regressor

Parameters

name: str

Name of the regressor column in data.

data: pd.DataFrame

Regressor data with ds and column named by name. It must cover every training and forecast date required by the model.

prior_scale: float | None = None

Strength of regularisation. If None, Prophet uses holidays_prior_scale.

standardize: bool | {auto} = "auto"

Whether Prophet standardises the regressor. "auto" standardises non-binary regressors.

mode: (additive, multiplicative) = "additive"
How the regressor affects the forecast. If None, uses the model’s seasonality_mode.