prophet.prophet()

Fit Prophet model and generate forecast.

Usage

prophet.prophet(
    train,
    params,
    test=None,
    horizon=None,
    seed=None,
)

Parameters

train: pd.DataFrame

Historic training data.

params: ProphetParams

Parameters controlling the model.

test: pd.DataFrame | None = None

Data containing the dates to forecast in a ds column. Typically a held-out test set or cross-validation fold.

horizon: int | None = None

Number of days to forecast, after the final date in train. To be used if there is no test set (e.g., if actually predicting into future with no data to compare against).

seed: int | None = None
Random seed (as randomness is used by prophet when estimating the prediction intervals, so a seed is needed to make them reproducible).

Returns

forecast: pd.DataFrame
Forecast dataframe.