plot.plot_error_over_time()
Plot error over time.
Usage
plot.plot_error_over_time(
error_df,
error_name,
metric,
area,
error_horizons,
)Parameters
error_df: pd.DataFrame-
Dataframe with errors for each fold, metric and area (as returned by forecast_errors()).
error_name: str-
Name of error column in
error_dfto plot. metric: str-
Name of ambulance metric to plot.
area: str-
Name of area to plot.
error_horizons: int | list[int] | tuple[int, …]-
One or more error horizons to plot, for example
42or[7, 42].