plot.plot_holiday_coverage()
Visualise when each holiday occurs over the whole time series.
Usage
plot.plot_holiday_coverage(
data,
start=None,
historic_end=None,
)Create a plot where the X-axis is the date, and then there is a row for each holiday in the dataset, marking each date the holiday is on. This can be used to understand which holidays are included, whether they cover the full range of dates in the dataset, and whether they project beyond the current end date of the historic data.
Parameters
data: pd.DataFrame-
Holidays data with one row for each holiday date (as returned by expand_holiday_windows()).
start: pd.Timestamp | None = None-
Start date for the visualisation.
historic_end: pd.Timestamp | None = None- Final date in the historic data, marked as a vertical line on the plot.